=======================================
CANADIAN CHARTER OF RIGHTS AND FREEDOMS
=======================================

Whereas Canada is founded upon principles that recognize the supremacy of
God and the rule of law:

GUARANTEE OF RIGHTS AND FREEDOMS
================================

Rights and freedoms in Canada
-----------------------------

1. The Canadian Charter of Rights and Freedoms guarantees the rights and freedoms
   set out in it subject only to such reasonable limits prescribed by law as can be
   demonstrably justified in a free and democratic society.

FUNDAMENTAL FREEDOMS
====================

Fundamental freedoms
--------------------

2. Everyone has the following fundamental freedoms:

   (a) freedom of conscience and religion;
   (b) freedom of thought, belief, opinion and expression, including freedom of the press and other media of communication;
   (c) freedom of peaceful assembly; and
   (d) freedom of association.

DEMOCRATIC RIGHTS
=================

Democratic rights of citizens
-----------------------------

3. Every citizen of Canada has the right to vote in an election of members of the
   House of Commons or of a legislative assembly and to be qualified for membership
   therein.

Maximum duration of legislative bodies
--------------------------------------

4. 

(1) No House of Commons and no legislative assembly shall continue for
    longer than five years from the date fixed for the return of the writs at a general
    election of its members.

Continuation in special circumstances
-------------------------------------

(2) In time of real or apprehended war, invasion or insurrection, a House of
    Commons may be continued by Parliament and a legislative assembly may be continued
    by the legislature beyond five years if such continuation is not opposed by
    the votes of more than one-third of the members of the House of Commons or the
    legislative assembly, as the case may be.

Annual sitting of legislative bodies
------------------------------------

5. There shall be a sitting of Parliament and of each legislature at least once every
    twelve months.

MOBILITY RIGHTS
===============

Mobility of citizens
--------------------

6. 

(1) Every citizen of Canada has the right to enter, remain in and leave
    Canada.

Rights to move and gain livelihood
----------------------------------

(2) Every citizen of Canada and every person who has the status of a permanent
    resident of Canada has the right

    (a) to move to and take up residence in any province; and
    (b) to pursue the gaining of a livelihood in any province.

Limitation
----------

(3) The rights specified in subsection (2) are subject to

    (a) any laws or practices of general application in force in a province other than
        those that discriminate among persons primarily on the basis of province of
        present or previous residence; and
    (b) any laws providing for reasonable residency requirements as a qualification
        for the receipt of publicly provided social services.

Affirmative action programs
---------------------------

(4) Subsections (2) and (3) do not preclude any law, program or activity that has
    as its object the amelioration in a province of conditions of individuals in that
    province who are socially or economically disadvantaged if the rate of employment
    in that province is below the rate of employment in Canada.

LEGAL RIGHTS
============

Life, liberty and security of person
------------------------------------

7. Everyone has the right to life, liberty and security of the person and the right
   not to be deprived thereof except in accordance with the principles of fundamental
   justice.

Search or seizure
-----------------

8. Everyone has the right to be secure against unreasonable search or seizure.

Detention or imprisonment
-------------------------

9. Everyone has the right not to be arbitrarily detained or imprisoned.

Arrest or detention
-------------------

10. Everyone has the right on arrest or detention

    (a) to be informed promptly of the reasons therefor;
    (b) to retain and instruct counsel without delay and to be informed of that right;
        and
    (c) to have the validity of the detention determined by way of habeas corpus and
        to be released if the detention is not lawful.

Proceedings in criminal and penal matters
-----------------------------------------

11. Any person charged with an offence has the right

    (a) to be informed without unreasonable delay of the specific offence;
    (b) to be tried within a reasonable time;
    (c) not to be compelled to be a witness in proceedings against that person in respect
        of the offence;
    (d) to be presumed innocent until proven guilty according to law in a fair and
        public hearing by an independent and impartial tribunal;
    (e) not to be denied reasonable bail without just cause;
    (f) except in the case of an offence under military law tried before a military tribunal,
        to the benefit of trial by jury where the maximum punishment for the offence
        is imprisonment for five years or a more severe punishment;
    (g) not to be found guilty on account of any act or omission unless, at the time of
        the act or omission, it constituted an offence under Canadian or international law
        or was criminal according to the general principles of law recognized by the community
        of nations;
    (h) if finally acquitted of the offence, not to be tried for it again and, if finally
        found guilty and punished for the offence, not to be tried or punished for it again;
        and

        (i) if found guilty of the offence and if the punishment for the offence has been
            varied between the time of commission and the time of sentencing, to the benefit
            of the lesser punishment.

Treatment or punishment
-----------------------

12. Everyone has the right not to be subjected to any cruel and unusual treatment
    or punishment.

Self-crimination
----------------

13. A witness who testifies in any proceedings has the right not to have any incriminating
    evidence so given used to incriminate that witness in any other proceedings,
    except in a prosecution for perjury or for the giving of contradictory evidence.

Interpreter
-----------

14. A party or witness in any proceedings who does not understand or speak the
    language in which the proceedings are conducted or who is deaf has the right to the
    assistance of an interpreter.

EQUALITY RIGHTS
===============

Equality before and under law and equal protection and benefit of law
---------------------------------------------------------------------

15. 

(1) Every individual is equal before and under the law and has the right to
    the equal protection and equal benefit of the law without discrimination and, in particular,
    without discrimination based on race, national or ethnic origin, colour, religion,
    sex, age or mental or physical disability.

Affirmative action programs
---------------------------

(2) Subsection (1) does not preclude any law, program or activity that has as its
    object the amelioration of conditions of disadvantaged individuals or groups including
    those that are disadvantaged because of race, national or ethnic origin, colour,
    religion, sex, age or mental or physical disability.

OFFICIAL LANGUAGES OF CANADA
============================

Official languages of Canada
----------------------------

16. 

(1) English and French are the official languages of Canada and have equality
    of status and equal rights and privileges as to their use in all institutions of the
    Parliament and government of Canada.

Official languages of New Brunswick
-----------------------------------

(2) English and French are the official languages of New Brunswick and have
    equality of status and equal rights and privileges as to their use in all institutions of
    the legislature and government of New Brunswick.

Advancement of status and use
-----------------------------

(3) Nothing in this Charter limits the authority of Parliament or a legislature to
    advance the equality of status or use of English and French.
    English and French linguistic communities in New Brunswick

16.1 

(1) The English linguistic community and the French linguistic community
    in New Brunswick have equality of status and equal rights and privileges, including
    the right to distinct educational institutions and such distinct cultural institutions as
    are necessary for the preservation and promotion of those communities.

Role of the legislature and government of New Brunswick
-------------------------------------------------------

(2) The role of the legislature and government of New Brunswick to preserve
    and promote the status, rights and privileges referred to in subsection (1) is affirmed.

Proceedings of Parliament
-------------------------

17.

(1) Everyone has the right to use English or French in any debates and other
    proceedings of Parliament.

Proceedings of New Brunswick legislature
----------------------------------------

(2) Everyone has the right to use English or French in any debates and other proceedings
    of the legislature of New Brunswick.

Parliamentary statutes and records
----------------------------------

18.

(1) The statutes, records and journals of Parliament shall be printed and published
    in English and French and both language versions are equally authoritative.

New Brunswick statutes and records
----------------------------------

(2) The statutes, records and journals of the legislature of New Brunswick shall
    be printed and published in English and French and both language versions are
    equally authoritative.

Proceedings in courts established by Parliament
-----------------------------------------------

19.

(1) Either English or French may be used by any person in, or in any pleading
    in or process issuing from, any court established by Parliament.

Proceedings in New Brunswick courts
-----------------------------------

(2) Either English or French may be used by any person in, or in any pleading in
    or process issuing from, any court of New Brunswick.

Communications by public with federal institutions
--------------------------------------------------

20.

(1) Any member of the public in Canada has the right to communicate with,
    and to receive available services from, any head or central office of an institution of
    the Parliament or government of Canada in English or French, and has the same
    right with respect to any other office of any such institution where

    (a) there is a significant demand for communications with and services from that
        office in such language; or
    (b) due to the nature of the office, it is reasonable that communications with and
        services from that office be available in both English and French.
        Communications by public with New Brunswick institutions

(2) Any member of the public in New Brunswick has the right to communicate
    with, and to receive available services from, any office of an institution of the legislature
    or government of New Brunswick in English or French.

Continuation of existing constitutional provisions
--------------------------------------------------

21. Nothing in sections 16 to 20 abrogates or derogates from any right, privilege
    or obligation with respect to the English and French languages, or either of them,
    that exists or is continued by virtue of any other provision of the Constitution of
    Canada.

Rights and privileges preserved
-------------------------------

22. Nothing in sections 16 to 20 abrogates or derogates from any legal or customary
    right or privilege acquired or enjoyed either before or after the coming into
    force of this Charter with respect to any language that is not English or French.

MINORITY LANGUAGE EDUCATIONAL RIGHTS
====================================

Language of instruction
-----------------------

23.

(1) Citizens of Canada

    (a) whose first language learned and still understood is that of the English or
        French linguistic minority population of the province in which they reside, or
    (b) who have received their primary school instruction in Canada in English or
        French and reside in a province where the language in which they received that
        instruction is the language of the English or French linguistic minority population
        of the province,

    have the right to have their children receive primary and secondary school instruction
    in that language in that province.

Continuity of language instruction
----------------------------------

(2) Citizens of Canada of whom any child has received or is receiving primary or
    secondary school instruction in English or French in Canada, have the right to have
    all their children receive primary and secondary school instruction in the same language.

Application where numbers warrant
---------------------------------

(3) The right of citizens of Canada under subsections (1) and (2) to have their
    children receive primary and secondary school instruction in the language of the
    English or French linguistic minority population of a province

    (a) applies wherever in the province the number of children of citizens who have
        such a right is sufficient to warrant the provision to them out of public funds of
        minority language instruction; and
    (b) includes, where the number of those children so warrants, the right to have
        them receive that instruction in minority language educational facilities provided
        out of public funds.

ENFORCEMENT
===========

Enforcement of guaranteed rights and freedoms
---------------------------------------------

24.

(1) Anyone whose rights or freedoms, as guaranteed by this Charter, have
    been infringed or denied may apply to a court of competent jurisdiction to obtain
    such remedy as the court considers appropriate and just in the circumstances.

Exclusion of evidence bringing administration of justice into disrepute
-----------------------------------------------------------------------

(2) Where, in proceedings under subsection (1), a court concludes that evidence
    was obtained in a manner that infringed or denied any rights or freedoms guaranteed
    by this Charter, the evidence shall be excluded if it is established that, having regard
    to all the circumstances, the admission of it in the proceedings would bring the administration
    of justice into disrepute.

GENERAL
=======

Aboriginal rights and freedoms not affected by Charter
------------------------------------------------------

25. The guarantee in this Charter of certain rights and freedoms shall not be construed
    so as to abrogate or derogate from any aboriginal, treaty or other rights or
    freedoms that pertain to the aboriginal peoples of Canada including

    (a) any rights or freedoms that have been recognized by the Royal Proclamation
        of October 7, 1763; and
    (b) any rights or freedoms that now exist by way of land claims agreements or
        may be so acquired.

Other rights and freedoms not affected by Charter
-------------------------------------------------

26. The guarantee in this Charter of certain rights and freedoms shall not be construed
    as denying the existence of any other rights or freedoms that exist in Canada.

Multicultural heritage
----------------------

27. This Charter shall be interpreted in a manner consistent with the preservation
    and enhancement of the multicultural heritage of Canadians.

Rights guaranteed equally to both sexes
---------------------------------------

28. Notwithstanding anything in this Charter, the rights and freedoms referred to
    in it are guaranteed equally to male and female persons.

Rights respecting certain schools preserved
-------------------------------------------

29. Nothing in this Charter abrogates or derogates from any rights or privileges
    guaranteed by or under the Constitution of Canada in respect of denominational,
    separate or dissentient schools.

Application to territories and territorial authorities
------------------------------------------------------

30. A reference in this Charter to a province or to the legislative assembly or legislature
    of a province shall be deemed to include a reference to the Yukon Territory
    and the Northwest Territories, or to the appropriate legislative authority thereof, as
    the case may be.

Legislative powers not extended
-------------------------------

31. Nothing in this Charter extends the legislative powers of any body or authority.

APPLICATION OF CHARTER
======================

Application of Charter
----------------------

32.

(1) This Charter applies

    (a) to the Parliament and government of Canada in respect of all matters within
        the authority of Parliament including all matters relating to the Yukon Territory
        and Northwest Territories; and
    (b) to the legislature and government of each province in respect of all matters
        within the authority of the legislature of each province.

Exception
---------

(2) Notwithstanding subsection (1), section 15 shall not have effect until three
    years after this section comes into force.

Exception where express declaration
-----------------------------------

33.

(1) Parliament or the legislature of a province may expressly declare in an
    Act of Parliament or of the legislature, as the case may be, that the Act or a provision
    thereof shall operate notwithstanding a provision included in section 2 or sections
    7 to 15 of this Charter.

Operation of exception
----------------------

(2) An Act or a provision of an Act in respect of which a declaration made under
    this section is in effect shall have such operation as it would have but for the provision
    of this Charter referred to in the declaration.

Five year limitation
--------------------

(3) A declaration made under subsection (1) shall cease to have effect five years
    after it comes into force or on such earlier date as may be specified in the declaration.

Re-enactment
------------

(4) Parliament or the legislature of a province may re-enact a declaration made
    under subsection (1).

Five year limitation
--------------------

(5) Subsection (3) applies in respect of a re-enactment made under subsection (4).

Citation
--------

34. This Part may be cited as the Canadian Charter of Rights and Freedoms.
